@@ -7,11 +7,11 @@ sub get {
     my @message;
 
 $message[0] = ("Warning:  Interactive Fortran should not run in
-background. Is L_SU running in the foreground? \n
+background. Is SeismicUnixGui running in the foreground? \n
 If it is not, on command line
 (1) enter:   'fg', return, return,
 	or 
-(2) run L_SU again, but without '&' \n
+(2) run SeismicUnixGui again, but without '&' \n
 	(immodpg_message=0)\n");
 	
 $message[1] =("Warning:  Corrupt layer in model
