@@ -3,18 +3,26 @@ package App::SeismicUnixGui::misc::L_SU_global_constants;
 use Moose;
 use Carp;
 
-my $L_SU;
+my $path4SeismicUnixGui;
+$path4SeismicUnixGui = $ENV{'SeismicUnixGui'};
 
 BEGIN {
-	use Env;
-	
-	if (length $ENV{'SeismicUnixGui'} ) {
-		
-			$L_SU = $ENV{'SeismicUnixGui'};
-			
-	} else {
-		$L_SU = '/usr/local/pl/App-SeismicUnixGui/lib/App/SeismicUnixGui';
-		carp $L_SU;
+
+	if ( length $ENV{'SeismicUnixGui'} ) {
+
+		$path4SeismicUnixGui = $ENV{'SeismicUnixGui'};
+
+	}
+	else {
+		my $dir = 'App-SeismicUnixGui/lib/App/SeismicUnixGui';
+		my $pathNfile =
+		  'App-SeismicUnixGui/lib/App/SeismicUnixGui/sunix/data/data_in.pm';
+		my $look  = `locate $pathNfile`;
+		my @field = split( $dir, $look );
+		$path4SeismicUnixGui = $field[0] . $dir;
+#		print(
+#"\nL22. Using default L_SU_global_constants, L_SU = $path4SeismicUnixGui\n"
+#		);
 	}
 }
 
@@ -97,7 +105,6 @@ BEGIN {
 #};
 #
 
-
 =head2 Default Tk settings
 
  _first_entry_num is normally 1 _max_entry_num is defaulted to
@@ -282,7 +289,8 @@ $alias_superflow_config_names[13] = 'temp';                          # make last
 my @alias_FileDialog_button_label;
 
 #$alias_FileDialog_button_label[0] = 'Data';
-$alias_FileDialog_button_label[0] = 'Flow';
+#$alias_FileDialog_button_label[0] = 'Flow';
+$alias_FileDialog_button_label[0] = 'Open';
 $alias_FileDialog_button_label[1] = 'SaveAs';
 
 my @file_dialog_type;
@@ -293,11 +301,13 @@ $alias_help_menubutton_label[0] = 'Install',
 
   my $alias_help_menubutton_label_h = { _Install => 'Install', };
 
-# in spec files Data_PL_SEISMIC, is not necessarily informed by DATA_DIR_IN and DATA_DIR_OUT
+# in spec files for when Data_PL_SEISMIC, may
+# not necessarily informed by DATA_DIR_IN and DATA_DIR_OUT
 $file_dialog_type[0] = 'Data_PL_SEISMIC',
 
-  # in spec files, Data is informed by DATA_DIR_IN and DATA_DIR_OUT
-  $file_dialog_type[1] = 'Data';
+# in spec files, for when Data is informed 
+# by DATA_DIR_IN and DATA_DIR_OUT
+$file_dialog_type[1] = 'Data';
 $file_dialog_type[2] = 'Path';
 $file_dialog_type[3] = 'Flow';
 $file_dialog_type[4] = 'SaveAs';
@@ -309,6 +319,7 @@ my $file_dialog_type_h = {
 	_Path             => 'Path',
 	_last_dir_in_path => 'last_dir_in_path',
 	_Flow             => 'Flow',
+	_Open             => 'Open',
 	_SaveAs           => 'SaveAs',
 	_Save             => 'Save',
 };
@@ -414,7 +425,7 @@ my $var = {
 	_one_character                 => '1',
 	_one_pixel                     => '1',
 	_one_pixel_borderwidth         => '1',
-	_program_title                 => 'SeismicUnixGui V0.80.00',
+	_program_title                 => 'SeismicUnixGui V0.80.6',
 	_project_selector_title        => 'Project Selector',
 	_l_suplot_title                => 'L_suplot',
 	_project_selector_title        => 'Project Selector',
@@ -596,6 +607,7 @@ sub get_developer_sunix_category_h {
 		_sufilter     => $developer_sunix_categories[3],
 		_sufrac       => $developer_sunix_categories[3],
 		_sufxdecon    => $developer_sunix_categories[3],
+		_sugroll      => $developer_sunix_categories[3],
 		_suk1k2filter => $developer_sunix_categories[3],
 		_sukfilter    => $developer_sunix_categories[3],
 		_sulfaf       => $developer_sunix_categories[3],
@@ -808,7 +820,7 @@ sub get_developer_sunix_category_h {
 		_sugprfb => $developer_sunix_categories[11],
 		_sukill  => $developer_sunix_categories[11],
 		_sumute  => $developer_sunix_categories[11],
-		_supad   => $developer_sunix_categories[11],		
+		_supad   => $developer_sunix_categories[11],
 		_susort  => $developer_sunix_categories[11],
 		_susplit => $developer_sunix_categories[11],
 		_suvcat  => $developer_sunix_categories[11],
@@ -875,24 +887,24 @@ my @sunix_datum_programs =
   ( "sudatumk2dr", "sudatumk2ds", "sukdmdcr", "sukdmdcs", );
 
 my @sunix_filter_programs = (
-	"subfilt",      "succfilt",   "sucddecon",  "sudipfilt",
-	"sueipofi",     "sufilter",   "sufrac",     "sufxdecon",
-	"suk1k2filter", "sukfilter",  "sulfaf",     "sumedian",
-	"supef",        "suphase",    "suphidecon", "supofilt",
-	"supolar",      "susmgauss2", "sutvband",
+	"subfilt", "succfilt", "sucddecon", "sudipfilt",
+	"sueipofi", "sufilter", "sufrac", "sufxdecon",
+	"sugroll",
+	"suk1k2filter", "sukfilter", "sulfaf", "sumedian",
+	"supef", "suphase", "suphidecon", "supofilt",
+	"supolar", "susmgauss2", "sutvband",
 );
 
 my @sunix_header_programs = (
-	"segyclean",    "segyhdrmod",  "segyhdrs",  "setbhed",
-	"su3dchart",   "suabshw",   "suaddhead",
-	"suaddstatics", "suahw",       "suascii",   "suazimuth",
-	"sucdpbin",     "suchart",     "suchw",     "sucliphead",
-	"sucountkey",   "sudumptrace", "suedit",    "sugethw",
-	"suhtmath",     "sukeycount",  "sulcthw",   "sulhead",
-	"supaste",      "surandhw",    "surange",   "susehw",
-	"sushw",        "sustatic",    "sustaticB", "sustaticrrs",
-	"sustrip",      "sutrcount",   "suutm",     "suxedit",
-	"swapbhed",
+	"segyclean",   "segyhdrmod", "segyhdrs",    "setbhed",
+	"su3dchart",   "suabshw",    "suaddhead",   "suaddstatics",
+	"suahw",       "suascii",    "suazimuth",   "sucdpbin",
+	"suchart",     "suchw",      "sucliphead",  "sucountkey",
+	"sudumptrace", "suedit",     "sugethw",     "suhtmath",
+	"sukeycount",  "sulcthw",    "sulhead",     "supaste",
+	"surandhw",    "surange",    "susehw",      "sushw",
+	"sustatic",    "sustaticB",  "sustaticrrs", "sustrip",
+	"sutrcount",   "suutm",      "suxedit",     "swapbhed",
 );
 
 my @sunix_inversion_programs = ( "suinvco3d", "suinvvxzco", "suinvzco3d", );
@@ -961,10 +973,8 @@ my @sunix_plot_programs = (
 );
 
 my @sunix_shapeNcut_programs = (
-	"suflip", "sugain", "sugprfb", "sukill",
-	"sumute", "susort", "susplit", "suwind",
-	"supad",
-	"suvcat",
+	"suflip", "sugain", "sugprfb", "sukill", "sumute", "susort",
+	"susplit", "suwind", "supad", "suvcat",
 );
 
 my @sunix_statsMath_programs = (
@@ -1006,33 +1016,79 @@ sub _get_global_libs {
 	my (@self) = @_;
 
 	# empty string is predefined herein
-	if ( length $L_SU ) {
+	if ( length $path4SeismicUnixGui ) {
 
 		#			print("L_SU_global_constants my L_SU = $L_SU\n");
 
 		my $global_libs = {
-			_configs             => $L_SU . '/configs',
-			_configs_big_streams => $L_SU . '/configs/big_streams',
-			_developer           => $L_SU . '/developer/Stripped',
-			_misc                => $L_SU . '/misc',
-			_param               => $L_SU . '/configs/',
-			_script              => $L_SU . '/script/',
-			_specs               => $L_SU . '/specs',
-			_sunix               => $L_SU . '/sunix',
-			_big_streams         => $L_SU . '/big_streams/',
-			_images              => $L_SU . '/images/',
-			_default_path        => './',
+			_configs             => $path4SeismicUnixGui . '/configs',
+			_configs_big_streams => $path4SeismicUnixGui
+			  . '/configs/big_streams',
+			_developer    => $path4SeismicUnixGui . '/developer/Stripped',
+			_misc         => $path4SeismicUnixGui . '/misc',
+			_param        => $path4SeismicUnixGui . '/configs/',
+			_script       => $path4SeismicUnixGui . '/script/',
+			_specs        => $path4SeismicUnixGui . '/specs',
+			_sunix        => $path4SeismicUnixGui . '/sunix',
+			_big_streams  => $path4SeismicUnixGui . '/big_streams/',
+			_images       => $path4SeismicUnixGui . '/images/',
+			_default_path => './',
 		};
 
 		return ($global_libs);
 
 	}
 	else {
-		print("L_SU_global_constants, global_libs, L_SU is missing\n");
-		return ();
+		my $path4SeismicUnixGui = _default_path();
+
+#		print("L1042, L_SU_global_constants, global_libs, L_SU was missing\n");
+#		print(
+#"\nL1044. L_SU_global_constants, Using default  L_SU = $path4SeismicUnixGui\n"
+#		);
+
+		my $global_libs = {
+			_configs             => $path4SeismicUnixGui . '/configs',
+			_configs_big_streams => $path4SeismicUnixGui
+			  . '/configs/big_streams',
+			_developer    => $path4SeismicUnixGui . '/developer/Stripped',
+			_misc         => $path4SeismicUnixGui . '/misc',
+			_param        => $path4SeismicUnixGui . '/configs/',
+			_script       => $path4SeismicUnixGui . '/script/',
+			_specs        => $path4SeismicUnixGui . '/specs',
+			_sunix        => $path4SeismicUnixGui . '/sunix',
+			_big_streams  => $path4SeismicUnixGui . '/big_streams/',
+			_images       => $path4SeismicUnixGui . '/images/',
+			_default_path => './',
+		};
+
+		return ($global_libs);
 	}
 
 }
+
+=head2 sub default_path
+
+When Environment variables
+can not be found within Perl
+
+=cut
+
+sub _default_path {
+
+	my ($self) = @_;
+
+	my $dir = 'App-SeismicUnixGui/lib/App/SeismicUnixGui';
+	my $pathNfile =
+	  'App-SeismicUnixGui/lib/App/SeismicUnixGui/sunix/data/data_in.pm';
+	my $look  = `locate $pathNfile`;
+	my @field = split( $dir, $look );
+	$path4SeismicUnixGui = $field[0] . $dir;
+
+	my $result = $path4SeismicUnixGui;
+
+	return ($result);
+}
+
 #
 #sub _get_path4SeismicUnixGui {
 #	my ($self) = @_;
@@ -1096,9 +1152,9 @@ sub _get_global_libs {
 ##		);
 ##		print("@{$directory_contents_specs[$parent_specs][$child_specs]}\n");
 #
-#=head2 Search all "spec"-relevant 
+#=head2 Search all "spec"-relevant
 #
-#directories start with 
+#directories start with
 #gui drectory listing
 #
 #=cut
@@ -1207,9 +1263,9 @@ sub _get_global_libs {
 ##		);
 ##		print("@{$directory_contents_su[$parent_su][$child_su]}\n");
 #
-#=head2 Search all "spec"-relevant 
+#=head2 Search all "spec"-relevant
 #
-#directories start with 
+#directories start with
 #gui drectory listing
 #
 #=cut
@@ -1434,21 +1490,21 @@ sub flow_type_href {
 #
 #}
 #
-#sub get_path4SeismicUnixGui {
-#	my ($self) = @_;
-#	if ( length $path4SeismicUnixGui ) {
-#
-#		my $result = $path4SeismicUnixGui;
-#		return ($result);
-#
-#	}
-#	else {
-#		print(
-#			"L_SU_global_constants, get_path4SeismicUnixGui,missing variable\n"
-#		);
-#	}
-#	return ();
-#}
+sub get_path4SeismicUnixGui {
+	my ($self) = @_;
+	if ( length $path4SeismicUnixGui ) {
+
+		my $result = $path4SeismicUnixGui;
+		return ($result);
+
+	}
+	else {
+		print(
+			"L_SU_global_constants, get_path4SeismicUnixGui,missing variable\n"
+		);
+	}
+	return ();
+}
 #
 #=head2 sub get_pathNmodule_spec
 #
@@ -1514,7 +1570,7 @@ sub help_menubutton_type_href {
 	return ($help_menubutton_type_h);
 }
 #
-#=head2 sub get_pathNfile2search 
+#=head2 sub get_pathNfile2search
 #
 #Useful directories to search
 #
@@ -1542,8 +1598,8 @@ sub help_menubutton_type_href {
 #=head2 Define
 #
 # variables
-# 
-#=cut	
+#
+#=cut
 #
 #		#		my @result_aref2;
 #		my @directory_contents;
@@ -1552,7 +1608,7 @@ sub help_menubutton_type_href {
 #=head2 Define
 #
 # directory search arrays
-# 
+#
 #=cut
 #
 #		my @PARENT_DIR = @{ $L_SU_global_constants->{_PARENT_DIR} };
@@ -1622,7 +1678,7 @@ sub help_menubutton_type_href {
 #
 #}
 #
-#=head2 sub _get_convert_pathNfile2search 
+#=head2 sub _get_convert_pathNfile2search
 #
 #Useful directories to search when
 #converting old perl files to new perl
@@ -1649,8 +1705,8 @@ sub help_menubutton_type_href {
 #=head2 Define
 #
 # variables
-# 
-#=cut	
+#
+#=cut
 #
 #	my @result_aref2;
 #	my @directory_contents_convert;
@@ -1659,8 +1715,8 @@ sub help_menubutton_type_href {
 #=head2 Define
 #
 # directory search arrays
-# 
-#=cut 
+#
+#=cut
 #
 #	my $GRANDPARENT_DIR = $path4SeismicUnixGui;
 #
@@ -1747,7 +1803,7 @@ sub help_menubutton_type_href {
 #
 #}
 #
-#=head2 sub _get_specs_pathNfile2search 
+#=head2 sub _get_specs_pathNfile2search
 #
 #Useful directories to search
 #
@@ -1766,8 +1822,8 @@ sub help_menubutton_type_href {
 #=head2 Define
 #
 # variables
-# 
-#=cut	
+#
+#=cut
 #
 #	my @result_aref2;
 #	my @directory_contents_specs;
@@ -1776,8 +1832,8 @@ sub help_menubutton_type_href {
 #=head2 Define
 #
 # directory search arrays
-# 
-#=cut 
+#
+#=cut
 #
 #	my $GRANDPARENT_DIR = $path4SeismicUnixGui;
 #
@@ -1845,7 +1901,7 @@ sub help_menubutton_type_href {
 #
 #}
 #
-#=head2 sub _get_tools_pathNfile2search 
+#=head2 sub _get_tools_pathNfile2search
 #
 #Useful directories to search
 #
@@ -1864,8 +1920,8 @@ sub help_menubutton_type_href {
 #=head2 Define
 #
 # variables
-# 
-#=cut	
+#
+#=cut
 #
 #	my @result_aref2;
 #	my @directory_contents_tools;
@@ -1874,8 +1930,8 @@ sub help_menubutton_type_href {
 #=head2 Define
 #
 # directory search arrays
-# 
-#=cut 
+#
+#=cut
 #
 #	my $GRANDPARENT_DIR = $path4SeismicUnixGui;
 #
@@ -2007,9 +2063,9 @@ sub help_menubutton_type_href {
 ##			"_SU_global_constants,get_path4convert_file,@{$directory_contents_convert[$parent_convert][$child_convert]}\n"
 ##		);
 #
-#=head2 Search all "convert"-relevant 
+#=head2 Search all "convert"-relevant
 #
-#directories start with 
+#directories start with
 #convert derectory listing
 #
 #=cut
@@ -2134,9 +2190,9 @@ sub help_menubutton_type_href {
 ##		);
 ##		print("@{$directory_contents_specs[$parent_specs][$child_specs]}\n");
 #
-#=head2 Search all "spec"-relevant 
+#=head2 Search all "spec"-relevant
 #
-#directories start with 
+#directories start with
 #gui drectory listing
 #
 #=cut
@@ -2245,9 +2301,9 @@ sub help_menubutton_type_href {
 ##		);
 ##		print("@{$directory_contents_tools[$parent_tools][$child_tools]}\n");
 #
-#=head2 Search all "spec"-relevant 
+#=head2 Search all "spec"-relevant
 #
-#directories start with 
+#directories start with
 #gui drectory listing
 #
 #=cut
@@ -2447,30 +2503,51 @@ sub global_libs {
 	my (@self) = @_;
 
 	# empty string is predefined herein
-	if ( length $L_SU ) {
+	if ( length $path4SeismicUnixGui ) {
 
-#		print("L_SU_global_constants my L_SU = $L_SU\n");
+		#		print("L_SU_global_constants my L_SU = $path4SeismicUnixGui\n");
 
 		my $global_libs = {
-			_configs             => $L_SU . '/configs',
-			_configs_big_streams => $L_SU . '/configs/big_streams',
-			_developer           => $L_SU . '/developer/Stripped',
-			_misc                => $L_SU . '/misc',
-			_param               => $L_SU . '/configs/',
-			_script              => $L_SU . '/script/',
-			_specs               => $L_SU . '/specs',
-			_sunix               => $L_SU . '/sunix',
-			_big_streams         => $L_SU . '/big_streams/',
-			_images              => $L_SU . '/images/',
-			_default_path        => './',
+			_configs             => $path4SeismicUnixGui . '/configs',
+			_configs_big_streams => $path4SeismicUnixGui
+			  . '/configs/big_streams',
+			_developer    => $path4SeismicUnixGui . '/developer/Stripped',
+			_misc         => $path4SeismicUnixGui . '/misc',
+			_param        => $path4SeismicUnixGui . '/configs/',
+			_script       => $path4SeismicUnixGui . '/script/',
+			_specs        => $path4SeismicUnixGui . '/specs',
+			_sunix        => $path4SeismicUnixGui . '/sunix',
+			_big_streams  => $path4SeismicUnixGui . '/big_streams/',
+			_images       => $path4SeismicUnixGui . '/images/',
+			_default_path => './',
 		};
 
 		return ($global_libs);
 
-	}
-	else {
-		carp("L_SU_global_constants, global_libs, L_SU is missing\n");
-		return ();
+	}else {
+		my $path4SeismicUnixGui = _default_path();
+
+#		print("L2526, L_SU_global_constants, global_libs, L_SU was missing\n");
+#		print(
+#"\nL22. Using default L_SU_global_constants, L_SU = $path4SeismicUnixGui\n"
+#		);
+
+		my $global_libs = {
+			_configs             => $path4SeismicUnixGui . '/configs',
+			_configs_big_streams => $path4SeismicUnixGui
+			  . '/configs/big_streams',
+			_developer    => $path4SeismicUnixGui . '/developer/Stripped',
+			_misc         => $path4SeismicUnixGui . '/misc',
+			_param        => $path4SeismicUnixGui . '/configs/',
+			_script       => $path4SeismicUnixGui . '/script/',
+			_specs        => $path4SeismicUnixGui . '/specs',
+			_sunix        => $path4SeismicUnixGui . '/sunix',
+			_big_streams  => $path4SeismicUnixGui . '/big_streams/',
+			_images       => $path4SeismicUnixGui . '/images/',
+			_default_path => './',
+		};
+
+		return ($global_libs);
 	}
 
 }
