@@ -28,21 +28,33 @@ package App::SeismicUnixGui::misc::L_SU_path;
 
 use Moose;
 use Carp;
+use Shell qw(echo);
 
 my $path4SeismicUnixGui_slash;
 my $path4SeismicUnixGui_colon;
+my $SeismicUnixGui;
+my $path;
 
 BEGIN {
-	use Env;
+
+    $SeismicUnixGui = ` echo \$SeismicUnixGui`;
+    chomp $SeismicUnixGui;
+	$path = $SeismicUnixGui;
 	
-	if (length $ENV{'SeismicUnixGui'} ) {
+#	print ("L_SU_global_constants, path=$path\n");
+	
+	if (length $SeismicUnixGui ) {
 		
-			$path4SeismicUnixGui_slash = $ENV{'SeismicUnixGui'};
+			$path4SeismicUnixGui_slash = $path;
 			$path4SeismicUnixGui_colon = $path4SeismicUnixGui_slash;
 			
 	} else {
-		$path4SeismicUnixGui_slash = '/usr/local/pl/App-SeismicUnixGui/lib/App/SeismicUnixGui';
-		carp $path4SeismicUnixGui_slash;
+		my $dir       = 'App-SeismicUnixGui/lib/App/SeismicUnixGui';
+	    my $pathNfile = 'App-SeismicUnixGui/lib/App/SeismicUnixGui/sunix/data/data_in.pm';
+	    my $look = `locate $pathNfile`;
+	    my @field= split($dir, $look);
+		$path4SeismicUnixGui_slash    = $field[0].$dir;
+#		print("\nL_SU_path, Using default: path4SeismicUnixGui_slash = $path4SeismicUnixGui_slash\n");
 	}
 }
 
@@ -211,6 +223,8 @@ my $specifications_path_w_colon = {
 	  . $developer_sunix_categories[3],
 	_sufxdecon => $global_libs_w_colon->{_specs} . '::'
 	  . $developer_sunix_categories[3],
+	_sugroll => $global_libs_w_colon->{_specs} . '::'
+	  . $developer_sunix_categories[3],	  
 	_suk1k2filter => $global_libs_w_colon->{_specs} . '::'
 	  . $developer_sunix_categories[3],
 	_sukfilter => $global_libs_w_colon->{_specs} . '::'
@@ -825,6 +839,8 @@ my $specifications_path_w_slash = {
 	  . $developer_sunix_categories[3],
 	_sufxdecon => $global_libs_w_slash->{_specs} . '/'
 	  . $developer_sunix_categories[3],
+	_sugroll => $global_libs_w_slash->{_specs} . '/'
+	  . $developer_sunix_categories[3],
 	_suk1k2filter => $global_libs_w_slash->{_specs} . '/'
 	  . $developer_sunix_categories[3],
 	_sukfilter => $global_libs_w_slash->{_specs} . '/'
