@@ -774,9 +774,9 @@ sub read_1col_aref {
 	my @X;
 	my $line;
 
-	print(
-"manage_files_by2,read_1col_aref,The output file name = $$ref_file_name\n"
-	);
+#	print(
+#"manage_files_by2,read_1col_aref,The output file name = $$ref_file_name\n"
+#	);
 
 	# set the counter
 
