@@ -14,8 +14,8 @@ my $time = localtime;
 
 $log_flows[0] =
 
-			
- ( "\t" . '$log->file(localtime);'. "\n".
+ ( "\t" .'my $time = localtime;'. "\n".			
+  "\t" . '$log->file(time);'. "\n".
   "\t" . '$log->file($flow[1]);' . "\n\n") ;
 
 sub section {
