@@ -15,7 +15,7 @@ package App::SeismicUnixGui::misc::param_widgets4pre_built_streams;
 =head2 DESCRIPTION
 
    manages the parameter labels, values and their
-   checkboxes in the mguis
+   checkboxes in the guis
 
 =head2 USE
 
@@ -1008,6 +1008,7 @@ sub redisplay_labels {
 	# my $length 			= $param_widgets->{_length};
 
 	if ($labels_w_aref) {
+		
 		for ( $i = $first; $i < $length; $i++ ) {
 
 			# print("i:$i   param_widgets,redisplay_labels length:$length\n");
