@@ -4,7 +4,7 @@
 
 =head2 SYNOPSIS 
 
- PERL PROGRAM NAME: L_SUV0.80.00.pl 
+ PERL PROGRAM NAME: L_SUV0.80.6.pl 
  AUTHOR: 	Juan Lorenzo
  DATE: 		June 22 2017 
 
@@ -74,7 +74,7 @@
 =cut 
 
 use Moose;
-our $VERSION = '0.70.60';
+our $VERSION = '0.80.6';
 
 extends 'App::SeismicUnixGui::misc::gui_history'=> { -version => 0.0.2 };
 use aliased 'App::SeismicUnixGui::misc::gui_history';
@@ -619,7 +619,7 @@ print join("\n", $top_menu_bar->bind($class) ), "\n";
 =cut
 
 	$main_href->{_file_menubutton} = $side_menu_frame->Menubutton(
-		-text               => 'File',
+		-text               => 'Flow',
 		-font               => $arial_16,
 		-height             => $var->{_1_character},
 		-relief             => 'flat',
@@ -649,7 +649,7 @@ print join("\n", $top_menu_bar->bind($class) ), "\n";
 #	);
 
 	# Flow is the only button enabled from the start
-	# in order to open a user-built perl flow
+	# Its purpose is to open a user-built perl flow
 	( $main_href->{_file_menubutton} )->separator;
 	$main_href->{_Flow_menubutton} = ( $main_href->{_file_menubutton} )->command(
 		-label     => @$alias_FileDialog_button_label[0],
@@ -720,21 +720,6 @@ contains side menus
 		-command            => [ \&_L_SU, 'set_save_button', \$Save_option ],
 	);
 
-#	my $Check_code_option = 'Check';
-#	$main_href->{_check_code_button} = $side_menu_frame->Button(
-#		-text               => 'Check',
-#		-font               => $arial_16,
-#		-height             => $var->{_1_character},
-#		-background         => $var->{_my_yellow},
-#		-foreground         => $var->{_my_black},
-#		-disabledforeground => $var->{_my_dark_grey},
-#		-activeforeground   => $var->{_my_white},
-#		-activebackground   => $var->{_my_dark_grey},
-#		-relief             => 'flat',
-#		-state              => 'disabled',
-#		-command            => [ \&_L_SU, 'check_code_button', \$Check_code_option ],
-#	);
-
 =head2 top_titles frame
 above the work frame
 contains Titles only 
@@ -2321,6 +2306,7 @@ in L_SU
 	-run_button
 	-FileDialog_button with one of 2
 	possible values: 'Flow', 'SaveAs'
+	possible values: 'Open', 'SaveAs'	
 	
 	-help_menubutton with possible value:
 	
