@@ -1,14 +1,16 @@
 package App::SeismicUnixGui::sunix::shapeNcut::sumute;
 
-=head1 DOCUMENTATION
-
 =head2 SYNOPSIS
 
- PACKAGE NAME:  SUMUTE - MUTE above (or below) a user-defined polygonal curve with	", 
- AUTHOR: Juan Lorenzo
- DATE:   
- DESCRIPTION:
- Version: 
+PACKAGE NAME: 
+
+AUTHOR:  
+
+DATE:
+
+DESCRIPTION:
+
+Version:
 
 =head2 USE
 
@@ -16,91 +18,200 @@ package App::SeismicUnixGui::sunix::shapeNcut::sumute;
 
 =head4 Examples
 
-=head3 SEISMIC UNIX NOTES
+=head2 SYNOPSIS
 
+=head3 SEISMIC UNIX NOTES
  SUMUTE - MUTE above (or below) a user-defined polygonal curve with	", 
+
 	   the distance along the curve specified by key header word 	
 
+
+
  sumute <stdin >stdout xmute= tmute= [optional parameters]		
 
+
+
  Required parameters:							
+
  xmute=		array of position values as specified by	
+
  			the `key' parameter				
+
  tmute=		array of corresponding time values (sec)	
+
  			in case of air wave muting, correspond to 	
- 			air blast duration				#
+
+ 			air blast duration				
+
   ... or input via files:						
+
  nmute=		number of x,t values defining mute		
+
  xfile=		file containing position values as specified by	
+
  			the `key' parameter				
+
  tfile=		file containing corresponding time values (sec)	
+
   ... or via header:							
+
  hmute=		key header word specifying mute time		
 
+
+
  Optional parameters:							
+
  key=offset		Key header word specifying trace offset 	
+
  				=tracl  use trace number instead	
+
  ntaper=0		number of points to taper before hard		
+
 			mute (sine squared taper)			
+
  mode=0	   mute ABOVE the polygonal curve			
+
 		=1 to zero BELOW the polygonal curve			
+
 		=2 to mute below AND above a straight line. In this case
+
 		 	xmute,tmute describe the total time length of   
+
 			the muted zone as a function of xmute the slope 
+
 			of the line is given by the velocity linvel=	
+
 	 	=3 to mute below AND above a constant velocity hyperbola
-			as in mode=2		use suputgthr; xmute,tmute describe the total time
+
+			as in mode=2 xmute,tmute describe the total time
+
 			length of the mute zone as a function of xmute,  
+
 			the velocity is given by the value of linvel=	
+
  		=4 to mute below AND above a user defined polygonal line
+
 			given by xmute, tmute pairs. The widths in time ", 
+
 			of the muted zone are given by the twindow vector
+
  linvel=330   		constant velocity for linear or hyperbolic mute	
+
  tm0=0   		time shift of linear or hyperbolic mute at	
+
 			 \'key\'=0					
+
  twindow=	vector of mute zone widths in time, operative only in mode=4
+
   ... or input via file:						
+
  twfile= 								
 
+
+
  Notes: 								
+
  The tmute interpolant is extrapolated to the left by the smallest time
+
  sample on the trace and to the right by the last value given in the	
+
  tmute array.								
 
+
+
  The files tfile and xfile are files of binary (C-style) floats.	
 
+
+
  In the context of this program "above" means earlier time and	
+
  "below" means later time (above and below as seen on a seismic section.
 
+
+
  The mode=2 option is intended for removing air waves. The mute is	
+
  is over a narrow window above and below the line specified by the	
+
  the line specified by the velocity "linvel". Here the values of     
+
  tmute, xmute or tfile and xfile define the total time width of the mute.
 
+
+
  If data are spatial, such as the (z-x) output of a migration, then    
+
  depth values are used in place of times in tmute and tfile. The value 
+
  of the depth sampling interval is given by the d1 header field	
+
  You must use the option key=tracl in sumute in this case.		
 
+
+
  Caveat: if data are seismic time sections, then tr.dt must be set. If 
+
  data are seismic depth sections, then tr.trid must be set to the value
+
  of TRID_DEPTH and the tr.d1 header field must be set.			
+
  To find the value of TRID_DEPTH:  					
+
  type: 								
+
      sukeyword trid							
+
 	and look for the entry for "Depth-Range (z-x) traces
 
 
+
+
+
  Credits:
 
+
+
 	SEP: Shuki Ronen
+
 	CWP: Jack K. Cohen, Dave Hale, John Stockwell
+
 	DELPHI: Alexander Koek added airwave mute.
+
       CWP: John Stockwell added modes 3 and 4
+
 	USBG: Florian Bleibinhaus added hmute + some range checks on mute times
+
  Trace header fields accessed: ns, dt, delrt, key=keyword, trid, d1
+
  Trace header fields modified: muts or mute
 
+
+
+=head2 User's notes (Juan Lorenzo)
+
+Normally, sumute can only apply one set muting coordinates to one file
+at a time. If you want to apply many different mute designs within
+the gathers of a single file, then you will need to generate previously
+a "multi-gather" mute-type parameter file.
+
+For when there is a multi-gather parameter file involved
+(Daniel Locci, March 2020)
+
+Pick x,t values in single a gather to mute surface waves and save in a 
+parfile, then use susplit to sepate gathers into ep, and use sumute_single_ep.pl. 
+ e.g,
+susplit < test.su > test_ep.su key=ep numlength=1
+
+The parfile can be concatenated using the Tool: Sucat
+
+gather_type           = ep,cdp,segy gathers you are muting
+multi_gather_par_file =
+multi_gather_su_file  = the su file which was muted interactively
+using the Tool: iTop_Mute  
+
+
+=cut
+
 =head2 CHANGES and their DATES
 
 =cut
@@ -108,30 +219,47 @@ package App::SeismicUnixGui::sunix::shapeNcut::sumute;
 use Moose;
 our $VERSION = '0.0.1';
 
+=head2 Import packages
+
+=cut
+
 use aliased 'App::SeismicUnixGui::misc::L_SU_global_constants';
-use App::SeismicUnixGui::misc::SeismicUnix qw($itop_mute_par_ $ibot_mute_par_);
+use App::SeismicUnixGui::misc::SeismicUnix
+  qw($go $in $itop_mute_par_ $ibot_mute_par_ $off $on $out $ps $to $suffix_ascii $suffix_bin 
+  $suffix_ps $suffix_segy $suffix_su $tmute $xmute);
 use aliased 'App::SeismicUnixGui::configs::big_streams::Project_config';
 use aliased 'App::SeismicUnixGui::misc::manage_files_by2';
-		
 use App::SeismicUnixGui::misc::control '0.0.3';
 use aliased 'App::SeismicUnixGui::misc::control';
+use aliased 'App::SeismicUnixGui::sunix::shapeNcut::susplit';
+use aliased 'App::SeismicUnixGui::misc::flow';
 
-use App::SeismicUnixGui::sunix::shapeNcut::susplit;
-use App::SeismicUnixGui::misc::flow;
+=head2 instantiation of packages
 
-use App::SeismicUnixGui::misc::SeismicUnix
-	qw($in $out $on $go $to $tmute $xmute $suffix_ascii $off $suffix_su $suffix_bin $temp_single_gather_par_file_mute );
+=cut
 
-
-my $get     = L_SU_global_constants->new();
-my $Project = Project_config->new();
+my $get              = L_SU_global_constants->new();
+my $Project          = Project_config->new();
+my $DATA_SEISMIC_SU  = $Project->DATA_SEISMIC_SU();
+my $DATA_SEISMIC_BIN = $Project->DATA_SEISMIC_BIN();
+my $DATA_SEISMIC_TXT = $Project->DATA_SEISMIC_TXT();
+my $PL_SEISMIC       = $Project->PL_SEISMIC();
+my $PS_SEISMIC       = $Project->PS_SEISMIC();
 
 my $var          = $get->var();
+my $on           = $var->{_on};
+my $off          = $var->{_off};
+my $true         = $var->{_true};
+my $false        = $var->{_false};
 my $empty_string = $var->{_empty_string};
+
 my ($imute_par_);
-my ( @tmute, @xmute, @output, @Steps, @gather_number, @par_file );
-my $PL_SEISMIC      = $Project->PL_SEISMIC();
-my $DATA_SEISMIC_SU = $Project->DATA_SEISMIC_SU();
+my (@tmute, @xmute, @output, @Steps, @gather_number, @par_file );
+
+=head2 Encapsulated
+hash of private variables
+
+=cut
 
 my $sumute = {
 	_par_gather_number_aref => '',
@@ -155,8 +283,8 @@ my $sumute = {
 	_xmute                  => '',
 	_Step                   => '',
 	_note                   => '',
-};
 
+};
 =head2 sub _get_par_sets
 
 =cut
@@ -181,17 +309,16 @@ sub _get_par_sets {
 
 		my ( @time_picks_aref2, @x_picks_aref2 );
 		my @par_gather;
-		my $multi_par_file_in;
+		my $multi_par_file_w_path;
 		my $row = 0;
 		my $inbound;
 		my @time_picks_aref;
 		my $par_gather_number;
 		my $par_gather_count;
 
-		$multi_par_file_in = $sumute->{_multi_gather_par_file};
-		$inbound           = $PL_SEISMIC . '/' . $multi_par_file_in;
-
-		# print("sumute,_get_par_sets, inbound=$inbound\n");
+		$multi_par_file_w_path = $sumute->{_multi_gather_par_file};
+		$inbound           = $multi_par_file_w_path;
+#		print("sumute,_get_par_sets, inbound=$inbound\n");
 
 =head2 read i/p file
 
@@ -221,8 +348,8 @@ sub _get_par_sets {
 			# print("sumute, _get_par_sets, gather type OK\n");
 
 		} else {
-			print("sumute, _get_par_sets, gather type missing in 1-to-2 places\n");
-			print("sumute, _get_par_sets, gather=--$gather_type-- and --$sumute->{_gather_type}--\n");
+			print("sumute, _get_par_sets, gather type missing in 1 or 2 places\n");
+			print("sumute, _get_par_sets, gather=--$gather_type-- versus --$sumute->{_gather_type}--\n");
 		}
 
 =head2 share values with namespace
@@ -298,20 +425,16 @@ for each gather
 
 }
 
+
+
 =head2 sub Step
 
-	Keeps track of actions for execution in the system
 collects switches and assembles bash instructions
 by adding the program name
 
-If there is a multi-gather parameter file involved
-Daniel Locci, March 2020:
-  NOTES: 
-  Pick x,t values in single a gather to mute surface waves and save in a 
-  parfile, then use susplit to sepate gathers into ep, and use sumute_single_ep.pl. 
-  e.g:
-  susplit < test.su > test_ep.su key=ep numlength=1
-
+Keeps track of actions for execution in the system
+collects switches and assembles bash instructions
+by adding the program name
 
 =cut
 
@@ -329,17 +452,16 @@ with multi_gather_su_file
 	if (   $sumute->{_multi_gather_par_file} ne $empty_string
 		&& $sumute->{_multi_gather_su_file} ne $empty_string
 		&& $sumute->{_par_gather_number_aref} ne $empty_string
-		&& $sumute->{_gather_type} ne $empty_string ) {
+		&& $sumute->{_gather_type} ne $empty_string )
+	{
 
 =head2 local definitions
 
 =cut			
 
-		my $file_in   = $sumute->{_multi_gather_su_file};
-		my $sufile_in = $file_in . $suffix_su;
-		my $inbound   = $DATA_SEISMIC_SU . '/' . $sufile_in;
+		my $inbound   = $sumute->{_multi_gather_su_file};
 
-		# print("sumute,Step, inbound = $inbound\n");
+#		print("sumute,Step, inbound = $inbound\n");
 
 =head2 get modules
 
@@ -377,7 +499,7 @@ with multi_gather_su_file
 		$susplit->suffix($suffix_su);
 		$susplit[0] = $susplit->Step();
 
-		# print("1. sumute, Step, susplit= $susplit[0] \n");
+		print("1. sumute, Step, susplit= $susplit[0] \n");
 
 =head2 clear past temporary, past
 single-gather split from composite su file
@@ -386,7 +508,7 @@ single-gather split from composite su file
 
 		my $delete_files = '.split_' . '*';
 		system("rm -rf $delete_files");
-		#
+		
 
 =head2 DEFINE 
 Collect FLOW(s)
@@ -395,11 +517,7 @@ Run flow in system independently of sumute
 
 =cut
 
-		my @items = (
-			$susplit[0],
-			$in,
-			$inbound
-		);
+		my @items = ( $susplit[0], $in, $inbound );
 		$flow[0] = $run->modules( \@items );
 
 =head2 RUN FLOW(s)
@@ -415,7 +533,7 @@ Run flow in system independently of sumute
 
 =cut
 
-		# print $flow[0];
+		print $flow[0];
 
 =head2 collect output split file names from the PL_SEISMIC directory
 
@@ -444,17 +562,24 @@ Run flow in system independently of sumute
 
 		if ( $number_of_split_files ne $number_of_par_sets ) {
 
-			print("\n sumute, Step,N.B.:    # of split files (= $number_of_split_files)\n");
-			print(" may not equal         # of par files   (= $number_of_par_sets) \n");
+			print(
+"\n sumute, Step,N.B.:    # of split files (= $number_of_split_files)\n"
+			);
+			print(
+" may not equal         # of par files   (= $number_of_par_sets) \n"
+			);
 
-		} elsif ( $sumute->{_multi_gather_par_file} eq $empty_string
-			&& $sumute->{_multi_gather_su_file} eq $empty_string ) {
+		}
+		elsif ($sumute->{_multi_gather_par_file} eq $empty_string
+			&& $sumute->{_multi_gather_su_file} eq $empty_string )
+		{
 
 			print(" sumute,Step, case2 \n");
 			$result = 'sumute' . $sumute->{_Step};
 			return ($result);
 
-		} else {
+		}
+		else {
 
 			# NADA
 		}
@@ -464,23 +589,27 @@ match parameter file to correct split data file
 
 =cut
 
-		( $time_picks_aref2, $x_picks_aref2, $first_name, $second_name ) = _get_par_sets();
+		( $time_picks_aref2, $x_picks_aref2, $first_name, $second_name ) =
+		  _get_par_sets();
 
 		my @par_gather_number = @{ $sumute->{_par_gather_number_aref} };
 
 		if ( $number_of_split_files >= 0 ) {
 
-			for ( my $i = 0; $i < $number_of_par_sets; $i++ ) {
+			for ( my $i = 0 ; $i < $number_of_par_sets ; $i++ ) {
 
 				# match on par file gather number
-				my $par_gather_number = '0' . $par_gather_number[$i].$suffix_su;
-				
-				my @matches           = grep {/$par_gather_number/} @split_file_names;
-				# print("2 sumute,Step,gather_number= $par_gather_number[$i]\n");
-				# print("2 sumute,Step,matches = @matches\n");
-				my $length = scalar @matches ;
+				my $par_gather_number =
+				  '0' . $par_gather_number[$i] . $suffix_su;
+
+				my @matches = grep { /$par_gather_number/ } @split_file_names;
+
+			   # print("2 sumute,Step,gather_number= $par_gather_number[$i]\n");
+			   # print("2 sumute,Step,matches = @matches\n");
+				my $length = scalar @matches;
+
 				# print("2 sumute,Step,mo. matches = $length\n");
-				
+
 =head2  error check
 get match to an 
 existing split files
@@ -489,20 +618,25 @@ existing split files
 
 				if ( $length > 1 ) {
 
-					# print("sumute,Step,match error Only one file SHOULD exist\n");
-					# print("sumute,Step,But matches= @matches\n");
+				# print("sumute,Step,match error Only one file SHOULD exist\n");
+				# print("sumute,Step,But matches= @matches\n");
 
-				} elsif ( ( scalar @matches ) == 1 ) {
+				}
+				elsif ( ( scalar @matches ) == 1 ) {
 
 					$split_file_matches[$i] = $matches[0];
 
-					# print("sumute,Step,split_file_matches[$i]=$split_file_matches[$i]\n");
+		# print("sumute,Step,split_file_matches[$i]=$split_file_matches[$i]\n");
 
-				} elsif ( ( scalar @matches ) == 0 ) {
+				}
+				elsif ( ( scalar @matches ) == 0 ) {
 
-					print("sumute,Step,match error At least one file SHOULD exist\n");
+					print(
+"sumute,Step,match error At least one file SHOULD exist\n"
+					);
 
-				} else {
+				}
+				else {
 					print("sumute,Step,error check\n");
 				}
 
@@ -521,7 +655,8 @@ i=0
 
 			$muted_output[0] = $split_file_matches[0];
 			$muted_output[0] =~ s/.su//;
-			$muted_output[0] = $PL_SEISMIC . '/' . $muted_output[0] . '_mute' . $suffix_su;
+			$muted_output[0] =
+			  $PL_SEISMIC . '/' . $muted_output[0] . '_mute' . $suffix_su;
 
 			my @time_picks = @{ @{$time_picks_aref2}[0] };
 			my @x_picks    = @{ @{$x_picks_aref2}[0] };
@@ -529,39 +664,40 @@ i=0
 			my $time_picks_w_commas = $control->commify( \@time_picks );
 			my $x_picks_w_commas    = $control->commify( \@x_picks );
 
- 			# print("2 sumute,Step,time_picks_aref2[0]=@time_picks\n");
- 			# print("sumute,Step,muted_output: $muted_output[0], case 0 \n");
- 			# print("sumute,Step,split_file_match: $split_file_matches[0], case 0 \n");
- 			# print("1 sumute,Step,time_picks_aref2[0]=@{@{$time_picks_aref2}[0]}\n");
- 			# print("1 sumute,Step,x_picks_w_commas=$x_picks_w_commas\n");
-  			# print("1 sumute,Step,time_picks_w_commas=$time_picks_w_commas\n");
+	 # print("2 sumute,Step,time_picks_aref2[0]=@time_picks\n");
+	 # print("sumute,Step,muted_output: $muted_output[0], case 0 \n");
+	 # print("sumute,Step,split_file_match: $split_file_matches[0], case 0 \n");
+	 # print("1 sumute,Step,time_picks_aref2[0]=@{@{$time_picks_aref2}[0]}\n");
+	 # print("1 sumute,Step,x_picks_w_commas=$x_picks_w_commas\n");
+	 # print("1 sumute,Step,time_picks_w_commas=$time_picks_w_commas\n");
 
-			$result
-				= ' sumute'
-				. $in
-				. $PL_SEISMIC . '/'
-				. $split_file_matches[0]
-				. $out
-				. $muted_output[0]
-				. $sumute->{_Step}
-				. ' tmute='
-				. $time_picks_w_commas
-				. ' xmute='
-				. $x_picks_w_commas . "\n";
+			$result =
+				' sumute'
+			  . $in
+			  . $PL_SEISMIC . '/'
+			  . $split_file_matches[0]
+			  . $out
+			  . $muted_output[0]
+			  . $sumute->{_Step}
+			  . ' tmute='
+			  . $time_picks_w_commas
+			  . ' xmute='
+			  . $x_picks_w_commas . "\n";
 
- 			# print("A sumute,Step,result so far \n$result\n");
+			# print("A sumute,Step,result so far \n$result\n");
 
 =head2 intermediate muting cases
 
 =cut
 
-			for ( my $i = 1; $i < ( $number_of_par_sets - 1 ); $i++ ) {
+			for ( my $i = 1 ; $i < ( $number_of_par_sets - 1 ) ; $i++ ) {
 
 				$muted_output[$i] = $split_file_matches[$i];
 
-	 			# print("2 sumute,Step,muted_output: $muted_output[$i] case i=$i\n");
+		   # print("2 sumute,Step,muted_output: $muted_output[$i] case i=$i\n");
 				$muted_output[$i] =~ s/.su//;
-				$muted_output[$i] = $PL_SEISMIC . '/' . $muted_output[$i] . '_mute' . $suffix_su;
+				$muted_output[$i] =
+				  $PL_SEISMIC . '/' . $muted_output[$i] . '_mute' . $suffix_su;
 
 				my @time_picks = @{ @{$time_picks_aref2}[$i] };
 				my @x_picks    = @{ @{$x_picks_aref2}[$i] };
@@ -569,19 +705,19 @@ i=0
 				my $time_picks_w_commas = $control->commify( \@time_picks );
 				my $x_picks_w_commas    = $control->commify( \@x_picks );
 
-				$result
-					= $result
-					. ' sumute'
-					. $in
-					. $PL_SEISMIC . '/'
-					. $split_file_matches[$i]
-					. $out
-					. $muted_output[$i]
-					. $sumute->{_Step}
-					. ' tmute='
-					. $time_picks_w_commas
-					. ' xmute='
-					. $x_picks_w_commas . "\n";
+				$result =
+					$result
+				  . ' sumute'
+				  . $in
+				  . $PL_SEISMIC . '/'
+				  . $split_file_matches[$i]
+				  . $out
+				  . $muted_output[$i]
+				  . $sumute->{_Step}
+				  . ' tmute='
+				  . $time_picks_w_commas
+				  . ' xmute='
+				  . $x_picks_w_commas . "\n";
 
 			}    # for all parameter sets
 
@@ -593,9 +729,12 @@ i=0
 
 			$muted_output[$last_case] = $split_file_matches[$last_case];
 
- 			# print("2 sumute,Step,muted_output: $muted_output[$last_case] case i=$last_case\n");
+# print("2 sumute,Step,muted_output: $muted_output[$last_case] case i=$last_case\n");
 			$muted_output[$last_case] =~ s/.su//;
-			$muted_output[$last_case] = $PL_SEISMIC . '/' . $muted_output[$last_case] . '_mute' . $suffix_su;
+			$muted_output[$last_case] =
+				$PL_SEISMIC . '/'
+			  . $muted_output[$last_case] . '_mute'
+			  . $suffix_su;
 
 			@time_picks = @{ @{$time_picks_aref2}[$last_case] };
 			@x_picks    = @{ @{$x_picks_aref2}[$last_case] };
@@ -603,22 +742,21 @@ i=0
 			$time_picks_w_commas = $control->commify( \@time_picks );
 			$x_picks_w_commas    = $control->commify( \@x_picks );
 
-			$result
-				= $result
-				. ' sumute'
-				. $in
-				. $PL_SEISMIC . '/'
-				. $split_file_matches[$last_case]
-				. $out
-				. $muted_output[$last_case]
-				. $sumute->{_Step}
-				. ' tmute='
-				. $time_picks_w_commas
-				. ' xmute='
-				. $x_picks_w_commas
-				."\n";
+			$result =
+				$result
+			  . ' sumute'
+			  . $in
+			  . $PL_SEISMIC . '/'
+			  . $split_file_matches[$last_case]
+			  . $out
+			  . $muted_output[$last_case]
+			  . $sumute->{_Step}
+			  . ' tmute='
+			  . $time_picks_w_commas
+			  . ' xmute='
+			  . $x_picks_w_commas . "\n";
 
- 			# print("2 sumute,Step,result for everything\n$result\n");
+			# print("2 sumute,Step,result for everything\n$result\n");
 
 =head2  concatenate muted results
 create concatenated output file name
@@ -627,8 +765,10 @@ create concatenated output file name
 
 			my $string = $sumute->{_multi_gather_su_file};
 			$string =~ s/.su//;
-			my $outbound_concatenated_mute_file = $DATA_SEISMIC_SU.'/'.$string . '_mute' . $suffix_su;
- 			# print(" sumute,Step, concatenated_mute_file: $outbound_concatenated_mute_file \n");
+			my $outbound_concatenated_mute_file =
+			  $DATA_SEISMIC_SU . '/' . $string . '_mute' . $suffix_su;
+
+# print(" sumute,Step, concatenated_mute_file: $outbound_concatenated_mute_file \n");
 
 =head2 cat first case
 	and then the rest in a loop
@@ -637,7 +777,7 @@ create concatenated output file name
 
 			$result = $result . 'cat' . ' ' . $muted_output[0] . ' ';
 
-			for ( my $i = 1; $i < $number_of_par_sets; $i++ ) {
+			for ( my $i = 1 ; $i < $number_of_par_sets ; $i++ ) {
 
 				$result = $result . $muted_output[$i] . ' ';
 
@@ -647,29 +787,39 @@ create concatenated output file name
 
 =cut
 
-#			$result = $result 
-#				. $out 
-#				. $outbound_concatenated_mute_file;
+			#			$result = $result
+			#				. $out
+			#				. $outbound_concatenated_mute_file;
 			# print("4. sumute,Step,result=$result \n");
 			return ($result);
 
-		} else {
+		}
+		else {
 			print("sumute,Step,unexpected number_of_split_file_matches \n");
 			return ();
 		}    # split_file matches exist
 
-	} elsif ( $sumute->{_multi_gather_par_file} eq $empty_string
-		&& $sumute->{_multi_gather_su_file} eq $empty_string ) {
+	}
+	elsif ($sumute->{_multi_gather_par_file} eq $empty_string
+		&& $sumute->{_multi_gather_su_file} eq $empty_string )
+	{
 
 		# print(" sumute,Step, case2 \n");
 		$result = 'sumute' . $sumute->{_Step};
 		return ($result);
 
-	} else {
+	}
+	else {
 		print(" sumute, Step, unexpected value\n");
-		print(" sumute, Step,multi_gather_par_file=$sumute->{_multi_gather_par_file} \n");
-		print(" sumute, Step,multi_gather_su_file=$sumute->{_multi_gather_su_file} \n");
-		print(" sumute, Step,par_gather_number_aref=$sumute->{_par_gather_number_aref} \n");
+		print(
+" sumute, Step,multi_gather_par_file=$sumute->{_multi_gather_par_file} \n"
+		);
+		print(
+" sumute, Step,multi_gather_su_file=$sumute->{_multi_gather_su_file} \n"
+		);
+		print(
+" sumute, Step,par_gather_number_aref=$sumute->{_par_gather_number_aref} \n"
+		);
 		print(" sumute, Step,gather_type=$sumute->{_gather_type} \n");
 		return ();
 
@@ -703,22 +853,22 @@ sub Steps {
 	my $run = flow->new();
 	my ( @items, @outbound );
 
-	for ( my $i = 1; $i <= $sumute->{_number_of_par_files}; $i++ ) {
+	for ( my $i = 1 ; $i <= $sumute->{_number_of_par_files} ; $i++ ) {
 		tmute( $sumute->{_tmute_array}[$i] );
 		xmute( $sumute->{_xmute_array}[$i] );
 
-		$outbound[$i]
-			= $DATA_SEISMIC_SU . '/'
-			. $sumute->{_file_in} . '_'
-			. $sumute->{_gather_type}
-			. $sumute->{_gather_number_array}[$i]
-			. $suffix_su;
+		$outbound[$i] =
+			$DATA_SEISMIC_SU . '/'
+		  . $sumute->{_file_in} . '_'
+		  . $sumute->{_gather_type}
+		  . $sumute->{_gather_number_array}[$i]
+		  . $suffix_su;
 
 		@items = (
-				  'suwind key='
-				. $sumute->{_gather_type} . ' min='
-				. $sumute->{_gather_number_array}[$i] . ' max='
-				. $sumute->{_gather_number_array}[$i],
+			'suwind key='
+			  . $sumute->{_gather_type} . ' min='
+			  . $sumute->{_gather_number_array}[$i] . ' max='
+			  . $sumute->{_gather_number_array}[$i],
 			$in,  $DATA_SEISMIC_SU . '/' . $sumute->{_file_in} . $suffix_su,
 			$to,  ' sumute ' . $sumute->{_Steps},
 			$out, $outbound[$i]
@@ -756,6 +906,7 @@ sub note {
 =cut
 
 sub clear {
+
 	$sumute->{_par_gather_number_aref} = '';
 	$sumute->{_gather_type}            = '';
 	$sumute->{_hmute}                  = '';
@@ -777,12 +928,14 @@ sub clear {
 	$sumute->{_xmute}   = '';
 	$sumute->{_Step}    = '';
 	$sumute->{_note}    = '';
+	
 }
 
-=head2 sub gather_type 
-for example can be ep cdp 
+=head2 sub gather_type
+
+for example, can be ep cdp 
 and refers to the types of gathers that
-are being muted
+are being muted.
 
 =cut
 
@@ -798,44 +951,26 @@ sub gather_type {
 	}
 }
 
-=head2 sub header_word
+
+=head2 sub header_word_mute
 
 
 =cut
 
-sub header_word {
+sub header_word_mute {
 
 	my ( $self, $key ) = @_;
 	if ( $key ne $empty_string ) {
 
 		$sumute->{_key}  = $key;
-		$sumute->{_note} = $sumute->{_note} . ' key=' . $sumute->{_key};
-		$sumute->{_Step} = $sumute->{_Step} . ' key=' . $sumute->{_key};
+		$sumute->{_note} = $sumute->{_note} . ' hmute=' . $sumute->{_key};
+		$sumute->{_Step} = $sumute->{_Step} . ' hmute=' . $sumute->{_key};
 
 	} else {
 		print("sumute, header_word, missing key,\n");
 	}
 }
 
-=head2 sub header_word
-
-
-=cut
-
-sub headerword {
-
-	my ( $self, $key ) = @_;
-	if ( $key ne $empty_string ) {
-
-		$sumute->{_key}  = $key;
-		$sumute->{_note} = $sumute->{_note} . ' key=' . $sumute->{_key};
-		$sumute->{_Step} = $sumute->{_Step} . ' key=' . $sumute->{_key};
-
-	} else {
-		print("sumute, headerword, missing key,\n");
-	}
-}
-
 =head2 sub hmute 
 
 
@@ -850,7 +985,8 @@ sub hmute {
 		$sumute->{_note}  = $sumute->{_note} . ' hmute=' . $sumute->{_hmute};
 		$sumute->{_Step}  = $sumute->{_Step} . ' hmute=' . $sumute->{_hmute};
 
-	} else {
+	}
+	else {
 		print("sumute, hmute, missing hmute,\n");
 	}
 }
@@ -869,14 +1005,14 @@ sub key {
 		$sumute->{_note} = $sumute->{_note} . ' key=' . $sumute->{_key};
 		$sumute->{_Step} = $sumute->{_Step} . ' key=' . $sumute->{_key};
 
-	} else {
+	}
+	else {
 		print("sumute, key, missing key,\n");
 	}
 }
 
 =head2 sub linvel 
 
-	The constant velocity used for linear or hyperbolic mutes
 
 =cut
 
@@ -889,199 +1025,14 @@ sub linvel {
 		$sumute->{_note}   = $sumute->{_note} . ' linvel=' . $sumute->{_linvel};
 		$sumute->{_Step}   = $sumute->{_Step} . ' linvel=' . $sumute->{_linvel};
 
-	} else {
+	}
+	else {
 		print("sumute, linvel, missing linvel,\n");
 	}
 }
 
-#=head2 Subroutine list
-# deprecated in version L_SU 0.4.0
-# March 2020 JML
-#
-# list of gather numbers to mute
-# There must be accompanying mute parameters in
-# additional files that correspond to each of the
-# shotgather (ep), cdp gather etc. numbers inside the list
-# for example,
-#   "1" should correspond to something like:
-#   "11" should correspond to something like:
-#
-# itop_mute_par_suFileName_binheaderType1
-# itop_mute_par_suFileName_binheaderType11
-#
-# e.g., itop_mute_par_All_cmp_ep11
-#
-# Usage 1:
-#To mute an array of shotpoint gathers (numbers in list)
-#  and su file name to which mute is applied
-#  sufile does NOT have a ".su" extension.
-#
-#Example:
-#       $sumute->list('top_mute_list',\$file_in[1],\$binheader[1]);
-#        file_in is the sunix file
-#        binheader is either offset,tracl  etc.
-#        whereas the gather type is either cdp, ep etc.
-#
-#=cut
-#
-#sub list {
-#	my ( $sub, $list, $ref_file_in, $ref_gather_type ) = @_;
-#
-#=head2 Error
-#
-#     Messages
-#
-#=cut
-#
-#	if ( defined($list) ) {
-#
-#		$sumute->{_list} = $list;
-#		$sumute->{_note} = $sumute->{_note} . ' list=' . $sumute->{_list};
-#
-#	} else {
-#		print(" Error: list name is missing in subroutine list");
-#
-#	}
-#
-#	if ($ref_file_in) {
-#		$sumute->{_file_in} = $$ref_file_in;
-#
-#print("file is $sumute->{_file_in}\n\n");
-#	} else {
-#		print(" Error: su file is missing in subroutine list");
-#
-#	}
-#	if ($ref_gather_type) {
-#		$sumute->{_gather_type} = $$ref_gather_type;
-#
-#print("gather_type is $sumute->{_gather_type}\n\n");
-#	} else {
-#		print(" Error: gather type is missing in subroutine list");
-#
-#	}
-#
-#=head2 Insert package
-#
-# into namespace
-#
-#=cut
-#
-#	use App::SeismicUnixGui::misc::manage_files_by;
-#	use aliased 'App::SeismicUnixGui::configs::big_streams::Project_config';
-#	my $Project = Project_config->new();
-#
-#=head2 Load
-#
-# variables into local namespace
-#
-#=cut
-#
-#	my ($numberOfFiles);
-#	my ( $ref_file_names, $i );
-#	my ( $file_number, $ref_values, $ref_numberOfValues );
-#	my (@sufile_in);
-#
-#=head2 read a list
-#
-# of file names
-#
-# testing
-#
-#  print(" number of files is $numberOfFiles\n");
-#  for (my $i=1; $i<=$numberOfFiles;$i++) {
-#       print("\n file $i is $$ref_file_names[$i]");
-#   }
-#
-#=cut
-#
-#	( $ref_file_names, $numberOfFiles )
-#		= manage_files_by::read_1col( \$sumute->{_list} );
-#
-#	if ($numberOfFiles) {
-#		$sumute->{_number_of_par_files} = $numberOfFiles;
-#	}
-#
-#=head2
-#
-# read contents of each file in the list
-# into arrays
-# each line of the list is a gather number and
-# indicates in which file the mute picks are found
-#
-# testing
-#
-#      $row = scalar @$ref_numberOfValues;
-#      print(" \nfor file #$file_number, number of rows is $row\n");
-#          print("par file is $par_file\n\n");
-#      for (my $i=0; $i<$row;$i++) {
-#          print("\n row $i contains $$ref_values[$i]");
-#          print(" i.e., $$ref_numberOfValues[$i] values\n");
-#          }
-#
-# line=2 is needed to skip the  first two lines
-# i.e. tnmo= vnmo=
-# first initializaed as 1 and then incremented
-#
-#=cut
-#
-#	for ( $file_number = 1; $file_number <= $sumute->{_number_of_par_files}; $file_number++ ) {
-#
-#		$sumute->{_gather_number_array}[$file_number] = $$ref_file_names[$file_number];
-#		$sumute->{_par_file_array}[$file_number]
-#			= $PL_SEISMIC . '/'
-#			. $imute_par_
-#			. $sumute->{_file_in} . '_'
-#			. $sumute->{_gather_type}
-#			. $sumute->{_gather_number_array}[$file_number];
-#		( $ref_values, $ref_numberOfValues ) = manage_files_by::read_par( \$sumute->{_par_file_array}[$file_number] );
-#
-#		my $row = scalar @$ref_numberOfValues;
-#		print(" \nfor file #$file_number, number of rows is $row\n");
-#		print("par file is $sumute->{_par_file_array}[$file_number]\n\n");
-#		for ( my $i = 0; $i < $row; $i++ ) {
-#			print("\n row $i contains $$ref_values[$i]");
-#			print(" i.e., $$ref_numberOfValues[$i] values\n");
-#		}
-#
-#=head2
-#
-# place contents of each file in the list
-# into an array
-# @output is an array referenced within the hash of this namespace
-#
-# testing
-#
-# print("for i=0 output is $sumute->{_output}[0]\n\n");
-# print("for i=$i tmute is $sumute->{_output}[$i]\n\n");
-# print("for i=0 output is $$ref_values[0]\n\n");
-# print("for i=1 output is $$ref_values[(0+1)]\n\n");
-#
-#          $sumute->{_output}[$i] =  $$ref_values[$i];
-#          print("for file=$file_number tmute is $sumute->{_tmute_array}[$file_number]\n\n");
-#          print("for file=$file_number xmute is $sumute->{_xmute_array}[$file_number]\n\n");
-#=cut
-#
-#		$sumute->{_row} = scalar @$ref_numberOfValues;
-#		for ( $i = 0; $i < $sumute->{_row}; $i = $i + 2 ) {
-#			$sumute->{_tmute_array}[$file_number] = $$ref_values[$i];
-#			$sumute->{_xmute_array}[$file_number] = $$ref_values[ ( $i + 1 ) ];
-#		}
-#	}    # end of reading par files
-#
-#=head2
-#
-#   Create sets a  mute flow for each T-X pick file ("par" file)
-#          print("for i=$i,and line=$line tmute is $sumute->{_tmute_array}[$line]\n\n");
-#          print("for i=$i,and line=$line xmute is $sumute->{_xmute_array}[$line]\n\n");
-#
-#
-#=cut
-#
-#}    # end of sub list
-
 =head2 sub mode 
 
-	Defines how the mute window is picked
 
 =cut
 
@@ -1094,24 +1045,28 @@ sub mode {
 		$sumute->{_note} = $sumute->{_note} . ' mode=' . $sumute->{_mode};
 		$sumute->{_Step} = $sumute->{_Step} . ' mode=' . $sumute->{_mode};
 
-	} else {
+	}
+	else {
 		print("sumute, mode, missing mode,\n");
 	}
 }
 
+
 =head2 sub multi_gather_par_file
 
 sumute can only handle one
 set of mute picks per file
 so a multi-gather file has to be
 split.
+
 A multi-gather par file for muting
 assembles these picks into one file
 using the same format as sunmo
 par files.
+
 However, currently sumute can not
 read multi-gather-par files.
-The user is unaware in L_SU GUI.
+The user is unaware in SeismicUnixGui
 
 multi-gather_par_files are 
 written like sunmo files with cdp numbers on the first line
@@ -1185,6 +1140,7 @@ sub multi_gather_su_file {
 	}
 }
 
+
 =head2 sub nmute 
 
 
@@ -1199,7 +1155,8 @@ sub nmute {
 		$sumute->{_note}  = $sumute->{_note} . ' nmute=' . $sumute->{_nmute};
 		$sumute->{_Step}  = $sumute->{_Step} . ' nmute=' . $sumute->{_nmute};
 
-	} else {
+	}
+	else {
 		print("sumute, nmute, missing nmute,\n");
 	}
 }
@@ -1218,11 +1175,32 @@ sub ntaper {
 		$sumute->{_note}   = $sumute->{_note} . ' ntaper=' . $sumute->{_ntaper};
 		$sumute->{_Step}   = $sumute->{_Step} . ' ntaper=' . $sumute->{_ntaper};
 
-	} else {
+	}
+	else {
 		print("sumute, ntaper, missing ntaper,\n");
 	}
 }
 
+=head2 sub offset_word 
+
+
+=cut
+
+sub offset_word {
+
+	my ( $self, $key ) = @_;
+	if ( $key ne $empty_string ) {
+
+		$sumute->{_key}  = $key;
+		$sumute->{_note} = $sumute->{_note} . ' key=' . $sumute->{_key};
+		$sumute->{_Step} = $sumute->{_Step} . ' key=' . $sumute->{_key};
+
+	} else {
+		print("sumute, offset_word, missing key,\n");
+	}
+}
+
+
 =head2 sub par 
 
 
@@ -1270,6 +1248,7 @@ sub par_directory {
 	}
 }
 
+
 =head2 sub par_file 
 
 
@@ -1290,25 +1269,6 @@ sub par_file {
 	}
 }
 
-=head2 sub parfile 
-
-
-=cut
-
-sub parfile {
-
-	my ( $self, $par ) = @_;
-	if ( $par ne $empty_string && $sumute->{_par_directory} ne $empty_string ) {
-
-		$sumute->{_par}  = $par;
-		$sumute->{_note} = $sumute->{_note} . ' par=' . $sumute->{_par_directory} . '/' . $sumute->{_par};
-		$sumute->{_Step} = $sumute->{_Step} . ' par=' . $sumute->{_par_directory} . '/' . $sumute->{_par};
-
-	} else {
-		print("sumute, parfile, missing par,or par_directory\n");
-	}
-}
-
 =head2 sub tfile 
 
 
@@ -1323,7 +1283,8 @@ sub tfile {
 		$sumute->{_note}  = $sumute->{_note} . ' tfile=' . $sumute->{_tfile};
 		$sumute->{_Step}  = $sumute->{_Step} . ' tfile=' . $sumute->{_tfile};
 
-	} else {
+	}
+	else {
 		print("sumute, tfile, missing tfile,\n");
 	}
 }
@@ -1342,14 +1303,14 @@ sub tm0 {
 		$sumute->{_note} = $sumute->{_note} . ' tm0=' . $sumute->{_tm0};
 		$sumute->{_Step} = $sumute->{_Step} . ' tm0=' . $sumute->{_tm0};
 
-	} else {
+	}
+	else {
 		print("sumute, tm0, missing tm0,\n");
 	}
 }
 
 =head2 sub tmute 
 
-	Defines the time (vertical-axis) portion of the window to mute
 
 =cut
 
@@ -1362,7 +1323,8 @@ sub tmute {
 		$sumute->{_note}  = $sumute->{_note} . ' tmute=' . $sumute->{_tmute};
 		$sumute->{_Step}  = $sumute->{_Step} . ' tmute=' . $sumute->{_tmute};
 
-	} else {
+	}
+	else {
 		print("sumute, tmute, missing tmute,\n");
 	}
 }
@@ -1378,14 +1340,17 @@ sub twindow {
 	if ( $twindow ne $empty_string ) {
 
 		$sumute->{_twindow} = $twindow;
-		$sumute->{_note}    = $sumute->{_note} . ' twindow=' . $sumute->{_twindow};
-		$sumute->{_Step}    = $sumute->{_Step} . ' twindow=' . $sumute->{_twindow};
+		$sumute->{_note} = $sumute->{_note} . ' twindow=' . $sumute->{_twindow};
+		$sumute->{_Step} = $sumute->{_Step} . ' twindow=' . $sumute->{_twindow};
 
-	} else {
+	}
+	else {
 		print("sumute, twindow, missing twindow,\n");
 	}
 }
 
+
+
 =head2 sub type 
 
 
@@ -1417,6 +1382,7 @@ sub type {
 	}
 }
 
+
 =head2 sub xfile 
 
 
@@ -1431,7 +1397,8 @@ sub xfile {
 		$sumute->{_note}  = $sumute->{_note} . ' xfile=' . $sumute->{_xfile};
 		$sumute->{_Step}  = $sumute->{_Step} . ' xfile=' . $sumute->{_xfile};
 
-	} else {
+	}
+	else {
 		print("sumute, xfile, missing xfile,\n");
 	}
 }
@@ -1450,20 +1417,21 @@ sub xmute {
 		$sumute->{_note}  = $sumute->{_note} . ' xmute=' . $sumute->{_xmute};
 		$sumute->{_Step}  = $sumute->{_Step} . ' xmute=' . $sumute->{_xmute};
 
-	} else {
+	}
+	else {
 		print("sumute, xmute, missing xmute,\n");
 	}
 }
 
 =head2 sub get_max_index
- 
+
 max index = number of input variables -1
  
 =cut
 
 sub get_max_index {
 	my ($self) = @_;
-	my $max_index = 15;
+	my $max_index = 16;
 
 	return ($max_index);
 }
